<?php

// ユーザ名
$user_name = 'guest@trial.seica.info';

// パスワード
$password = 'trial';

// スキーマURI
define('SEICA_FULLSET',   'http://schema.seica.info/SeicaCatalog/2002/');
define('SEICA_ESSENTIAL', 'http://schema.seica.info/SeicaCatalog/Essential/2002/');

// ライブラリを読み込む
include_once 'SOAP/Client.php';

// SOAPクライアントを作る
$seica =& new Soap_Client('./Seica.wsdl');


// -----------------------------------------------
// ユーティリティ関数
// -----------------------------------------------
// ハッシュキーを取得する
function getHashKey($password)
{
  return md5Base64(md5Base64($password)
    . (int)gmstrftime('%Y')
    . (int)gmstrftime('%m')
    . (int)gmstrftime('%d')
    . (int)gmstrftime('%H')
    . (int)gmstrftime('%M')
  );
}

// Base64エンコード化されたMD5ハッシュ値を取得する
function md5Base64($key)
{
  return base64_encode(pack("H*", md5($key)));
}


// -----------------------------------------------
// SOAPアクセス部
// -----------------------------------------------
// スキーマリストを取得する（このプログラムでは未使用）
function getSchemaList($method_name)
{
  global $user_name, $password, $seica;

  $params = array(
    'User'       => $user_name,
    'HashKey'    => getHashKey($password),
    'MethodName' => $method_name,
  );

  $response = $seica->call('GetSchemaList', $params);
  return $response;
}

// カタログを検索する
function queryCatalog($query_string)
{
  global $user_name, $password, $seica;

  $params = array(
    'User'        => $user_name,
    'HashKey'     => getHashKey($password),
    'QueryString' => $query_string,
    'SchemaUri'   => SEICA_ESSENTIAL,
    'Namespaces'  => 'xmlns:seica = ' . SEICA_ESSENTIAL,
  );

  $response = $seica->call('QueryCatalog', $params);
  return $response;
}

// カタログを取得する
function getCatalog($catalog_no)
{
  global $user_name, $password, $seica;

  $params = array(
    'User'      => $user_name,
    'HashKey'   => getHashKey($password),
    'CatalogNo' => $catalog_no,
    'SchemaUri' => SEICA_FULLSET,
  );

  $response = $seica->call('GetCatalog', $params);
  return $response;
}


// -----------------------------------------------
// 検索結果を表示する
function printQueryCatalog()
{
?>
<table>
<tr>
  <th>カタログ番号</th>
  <th>原産地</th>
  <th>品名</th>
  <th>栽培区分</th>
  <th>最終更新日</th>
</tr>
<?php
  // 検索種を判断する
  if (isset($_GET['pref'])) {
    $type = '原産地';
    $query = $_GET['pref'];
  } else if (isset($_GET['vegetable'])) {
    $type = '品名';
    $query = $_GET['vegetable'];
  }

  // APIを呼び出す
  $response = queryCatalog("seica:Catalog[seica:{$type} = '{$query}']");

  // 個々の結果を出力する
  foreach ($response->ROOT as $res) {
?>
<tr>
  <td>
    <a href="<?php echo $_SERVER['PHP_SELF'] . '?catalog=' . $res->公開用コード; ?>">
      <?php echo $res->公開用コード; ?>
    </a>
  </td>
  <td><?php echo $res->原産地; ?></td>
  <td><?php echo $res->品名; ?></td>
  <td><?php echo $res->栽培区分; ?></td>
  <td><?php echo $res->最終更新日; ?></td>
</tr>
<?php
  }
?>
</table>
<?php
}


// -----------------------------------------------
// 出力メイン部
// -----------------------------------------------
// カタログを表示する
function printGetCatalog()
{
  // APIを呼び出す
  $response = getCatalog($_GET['catalog']);
  $catalog = $response->ROOT->Catalog;

  // 取得できたものを全て出力する
?>
<h1>カタログ詳細: <?php echo $catalog->生産物情報->品名; ?></h1>

<h2>公開用コード</h2>
<p><?php echo $catalog->公開用コード; ?></p>

<h2>システム情報</h2>
<dl>
  <dt>最終更新日</dt>
  <dd><?php echo $catalog->システム情報->最終更新日; ?></dd>
  <dt>有効期限</dt>
  <dd><?php echo $catalog->システム情報->有効期限; ?></dd>
  <dt>初回登録日</dt>
  <dd><?php echo $catalog->システム情報->初回登録日; ?></dd>
  <dt>参照回数</dt>
  <dd><?php echo $catalog->システム情報->参照回数; ?></dd>
  <dt>編集者</dt>
  <dd><?php echo $catalog->システム情報->編集者; ?></dd>
</dl>

<h2>生産者情報</h2>
<dl>
  <dt>生産者名</dt>
  <dd><?php echo $catalog->生産者情報->生産者名; ?></dd>
  <dt>郵便番号</dt>
  <dd><?php echo $catalog->生産者情報->郵便番号; ?></dd>
  <dt>総耕地面積</dt>
  <dd><?php echo $catalog->生産者情報->総耕地面積; ?></dd>
  <dt>農産物</dt>
  <dd>
    <ol>
<?php
  foreach ($catalog->生産者情報->農産物 as $vegetable) {
    echo "<li>{$vegetable->品目}</li>\n";
  }
?>
    </ol>
  </dd>
</dl>

<h2>生産物情報</h2>
<dl>
  <dt>青果標準品名コード</dt>
  <dd><?php echo $catalog->生産物情報->青果標準品名コード; ?></dd>
  <dt>大分類コード</dt>
  <dd><?php echo $catalog->生産物情報->大分類コード; ?></dd>
  <dt>中分類コード</dt>
  <dd><?php echo $catalog->生産物情報->中分類コード; ?></dd>
  <dt>品名</dt>
  <dd>
    <a href="<?php echo $_SERVER['PHP_SELF'] . '?vegetable=' . $catalog->生産物情報->品名; ?>">
      <?php echo $catalog->生産物情報->品名; ?>
    </a>
  </dd>
  <dt>分類</dt>
  <dd><?php echo $catalog->生産物情報->分類; ?></dd>
  <dt>栽培面積</dt>
  <dd><?php echo $catalog->生産物情報->栽培面積; ?></dd>
  <dt>栽培区分</dt>
  <dd><?php echo $catalog->生産物情報->栽培区分; ?></dd>
  <dt>品種</dt>
  <dd>
    <ol>
<?php
  foreach ($catalog->生産物情報->品種 as $kind) {
    echo "<li>{$kind->品種名}</li>\n";
  }
?>
    </ol>
  </dd>
</dl>

<h2>取引情報</h2>
<dl>
  <dt>原産地</dt>
  <dd><?php echo $catalog->取引情報->原産地; ?></dd>
  <dt>出荷者名称</dt>
  <dd><?php echo $catalog->取引情報->出荷者名称; ?></dd>
  <dt>代表者</dt>
  <dd><?php echo $catalog->取引情報->代表者; ?></dd>
  <dt>郵便番号</dt>
  <dd><?php echo $catalog->取引情報->郵便番号; ?></dd>
  <dt>住所</dt>
  <dd><?php echo $catalog->取引情報->住所; ?></dd>
  <dt>電話番号</dt>
  <dd><?php echo $catalog->取引情報->電話; ?></dd>
  <dt>組織区分</dt>
  <dd><?php echo $catalog->取引情報->組織区分; ?></dd>
</dl>
<?php
}

// -----------------------------------------------
// 検索フォームを表示する
function printSearchForm()
{
?>
<form action="<?php echo $_SERVER['PHP_SELF']; ?>" method="get">
  原産地: <input type="text" name="pref" value="" />
  <input type="submit" value="検索" />
</form>
<form action="<?php echo $_SERVER['PHP_SELF']; ?>" method="get">
  品名: <input type="text" name="vegetable" value="" />
  <input type="submit" value="検索" />
</form>
<?php
}


// -----------------------------------------------
// 出力呼び出し部
// -----------------------------------------------
if (isset($_GET['pref']) || isset($_GET['vegetable'])) {
  // カタログを検索する
  printQueryCatalog();
} else if (isset($_GET['catalog'])) {
  // カタログを表示する
  printGetCatalog();
} else {
  // 検索フォームを表示する
  printSearchForm();
}

?>
