<?php

// ライブラリを読み込む
require_once 'HTTP/Client.php';

// Google Calendarの独自要素の名前空間
define('NS_GD', 'http://schemas.google.com/g/2005');

// HTTP-Clientオブジェクトを生成する
$http_client = new HTTP_Client();


// -----------------------------------------------
// メイン処理部
// -----------------------------------------------
// ライブラリを用いて外部のデータを取得する
function getContent($token, $uri)
{
  global $http_client;

  // トークンを問い合わせのヘッダに入れる
  $http_client->setDefaultHeader('Authorization', 'AuthSub token="' . $token . '"');

  // 外部のデータを取得する
  $result_code = $http_client->get($uri);

  // エラー処理
  if ($result_code != 200) {
    die('An error occured');
  }

  // 正常に処理が出来たので、データを返す
  $response = $http_client->currentResponse();
  return $response['body'];
}

// 引数がGoogle Calendarのデータとして出力する
function showCalendar($content)
{
?>
<table>
  <tr>
    <th>日時</th>
    <th>予定</th>
    <th>説明</th>
    <th>場所</th>
  </tr>
<?php
  // 文字列を解析する
  $xml = simplexml_load_string($content);

  // 個々の予定に対して出力を行う
  foreach ($xml->entry as $entry) {
    // Google Calendar独自要素を取得する
    $gd = $entry->children(NS_GD);

    // 予定の開始時刻をUNIXタイムへ変換する
    $startTime = strtotime($gd->when->attributes()->startTime);
?>
  <tr>
    <td><?php echo strftime("%Y-%m-%d %H:%M", $startTime); ?></td>
    <td><?php echo $entry->title; ?></td>
    <td><?php echo $entry->content; ?></td>
    <td><?php echo $gd->where->attributes()->valueString; ?></td>
  </tr>
<?php
  }
?>
</table>
<?php
}


// -----------------------------------------------
// 出力部
// -----------------------------------------------
// Google Calendarからのコールバックか
if (isset($_GET['token'])) {
  // トークンを再取得する
  $content = getContent($_GET['token'], 'http://www.google.com/accounts/AuthSubSessionToken');
  list(, $token) = explode('=', $content);
  $token = trim($token);

  // 再取得したトークンをpassパラメータに渡してリダイレクトする
  @header('Location: ./calendar.php?pass=' . $token);
  @header('HTTP/1.x 301');

  // ここで終了
  exit();
} else {
  // 再取得したトークンを用いてデータを取得する
  $content = getContent($_GET['pass'], 'http://www.google.com/calendar/feeds/default/private/full?orderby=starttime');

  // データを出力する
  showCalendar($content);
}

?>
